#include "DrawingManager.h"

#include "INativeDrawingContext.h"
#include "DrawingSurface.h"
#include "DrawingContext.h"
#include "CairoInterface.h"

DrawingManager::DrawingManager()
{
    mCairoInterface = CairoInterface::Create();
}

std::unique_ptr<DrawingManager> DrawingManager::Create()
{
    return std::make_unique<DrawingManager>();
}

void DrawingManager::InitalizeSurface(unsigned width, unsigned height)
{
    mDrawingSurface = DrawingSurface::Create();
    mDrawingSurface->SetSize(width, height);

    if (mCairoInterface)
    {
        mCairoInterface->InitializeSurface(mDrawingSurface.get());
    }
}

void DrawingManager::InitializeContext()
{
    mDrawingContext = DrawingContext::Create();

    if (mCairoInterface && mDrawingSurface)
    {
        mCairoInterface->InitializeContext(mDrawingContext.get(), mDrawingSurface.get());
    }
}

void DrawingManager::AddText(TextElement* text)
{
    if (!mDrawingContext)
    {
        InitializeContext();
    }

    if (!mDrawingContext)
    {
        return;
    }

    if (mCairoInterface)
    {
        mCairoInterface->AddText(text, mDrawingContext.get());
    }
}

void DrawingManager::RenderToFile(const std::string& path)
{
    if (mDrawingSurface && mCairoInterface)
    {
        mCairoInterface->RenderToFile(mDrawingSurface.get(), path);
    }
}
