#include "CairoInterface.h"

#include "DrawingSurface.h"
#include "DrawingContext.h"
#include "CairoDrawingSurface.h"
#include "CairoDrawingContext.h"
#include "TextElement.h"

#include <cairo.h>


std::unique_ptr<CairoInterface> CairoInterface::Create()
{
    return std::make_unique<CairoInterface>();
}

void CairoInterface::InitializeSurface(DrawingSurface* surface)
{
    auto native_surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
            surface->GetWidth(), surface->GetHeight());

    auto cairo_surface = CairoDrawingSurface::Create(native_surface);
    surface->SetNativeSurface(std::move(cairo_surface));
}

void CairoInterface::InitializeContext(DrawingContext* context, DrawingSurface* surface)
{
    auto cairo_surface = dynamic_cast<CairoDrawingSurface*>(surface->GetNativeSurface());
    auto native_context = cairo_create(cairo_surface->GetNativeSurface());

    auto cairo_context = CairoDrawingContext::Create(native_context);
    context->SetNativeContext(std::move(cairo_context));
}

void CairoInterface::RenderToFile(DrawingSurface* surface, const std::string& path)
{
    auto cairo_surface = dynamic_cast<CairoDrawingSurface*>(surface->GetNativeSurface());
    cairo_surface_write_to_png (cairo_surface->GetNativeSurface(), path.c_str());
}

void CairoInterface::AddText(TextElement* text, DrawingContext* context)
{
    auto cairo_context = dynamic_cast<CairoDrawingContext*>(context->GetNativeContext());
    auto native_context = cairo_context->GetNativeContext();

    cairo_select_font_face (native_context, "serif", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
    cairo_set_font_size (native_context, 32.0);
    cairo_set_source_rgb (native_context, 0.0, 0.0, 1.0);
    cairo_move_to(native_context, 10.0, 50.0);
    cairo_show_text(native_context, text->GetContent().c_str());
}
